@@ -3,9 +3,12 @@
 
 # pip install -U twine wheel setuptools
 
+git commit -am "$2"
+git push
 git tag -l | cat
 git tag -a "$1" -m "$2"
 python setup.py sdist
 python setup.py bdist_wheel
 twine check dist/*
-twine uplaod dist/"qary-$1"*
+twine upload dist/"qary-$1"*
+git push --tag
